5.13 Operating System (OS)
==========================

It describes an Operating System.

Type: :py:class:`~otupy.profiles.ctxd.data.os.OS` (:py:class:`~otupy.types.base.record.Record`)

.. list-table::
   :widths: 3 4 4 3 40
   :header-rows: 1

   * - ID
     - Name
     - Type
     - #
     - Description
   * - 1
     - name
     - ``str``
     - 1
     - Name of the OS.
   * - 2
     - version
     - ``str``
     - 1
     - Version of the OS.
   * - 3
     - family
     - ``str``
     - 1
     - Family of the OS.
   * - 4
     - type
     - ``str``
     - 1
     - Type of the OS.

